//============================================================================
//
// KRotation screen saver for KDE
// Copyright (C) 2004 Georg Drenkhahn
// $Id: sspreviewarea.cpp 753878 2007-12-28 17:37:07Z uwolfer $
//
//============================================================================

#include "sspreviewarea.h"
#include "sspreviewarea.moc"

SsPreviewArea::SsPreviewArea(QWidget* parent)
   : QWidget(parent)
{
}

void SsPreviewArea::resizeEvent(QResizeEvent* e)
{
   emit resized(e);
}

